Returns a named list where each entry is a data frame of
(x, y, gene) transcript positions. The top-level name mirrors
names(fov_obj@molecules) (typically "molecules" for CosMx/Xenium).
Returns a named list where each entry is a data frame of
(x, y, gene) transcript positions. The top-level name mirrors
names(fov_obj@molecules) (typically "molecules" for CosMx/Xenium).