Register a direct conversion path between two file formats
Source:R/FormatRegistry.R
RegisterDirectPath.RdDirect paths bypass the Seurat hub for efficiency (e.g., h5ad <-> h5seurat can be converted via direct HDF5 operations without loading into memory).