Register a file format with its load and save functions
Source:R/FormatRegistry.R
RegisterFormat.RdRegister a file format with its load and save functions
R/FormatRegistry.R
RegisterFormat.RdRegister a file format with its load and save functions