This function converts an HDF5 group to an R list, properly handling datasets with 3 or more dimensions (which fail with standard as.list). This is needed for Squidpy UMAP data that stores 3D arrays.
This function converts an HDF5 group to an R list, properly handling datasets with 3 or more dimensions (which fail with standard as.list). This is needed for Squidpy UMAP data that stores 3D arrays.