Convert a SpatialData zarr store to a standard anndata zarr store
Source:R/SpatialData.R
SpatialDataToZarr.RdExtracts the anndata table from a SpatialData store and writes it as a standalone anndata zarr store (without the SpatialData wrapper).