Write spatial coordinates as a SpatialData shapes directory
Source:R/SpatialData.R
dot-write_spatialdata_shapes.RdWrites a zarr DataFrame with x, y, and radius columns following the SpatialData shapes specification.
R/SpatialData.R
dot-write_spatialdata_shapes.RdWrites a zarr DataFrame with x, y, and radius columns following the SpatialData shapes specification.