Progress bars are useful ways of getting updates on how close a task is to
completion. However, they can get in the way of RMarkdown documents with
lots of unnecesssary printing. PB is a convenience function that
creates progress bars with the following defaults
char = '='style = 3file = stderr()
Value
An object of class txtProgressBar
Examples
# \donttest{
pb <- scConvert:::PB()
for (i in 1:10) {
utils::setTxtProgressBar(pb, i / 10)
}
close(pb)
# }