Wrap a standard anndata zarr store as a SpatialData store
Source:R/SpatialData.R
ZarrToSpatialData.RdTakes an existing anndata zarr store and wraps it as a SpatialData store by creating the SpatialData directory layout and placing the anndata store as a table.