Reads the highest resolution level from an OME-NGFF zarr image. The image is stored as a chunked zarr array with multiscales metadata describing axes and resolution levels. Only the first dataset (highest resolution) is read.
Reads the highest resolution level from an OME-NGFF zarr image. The image is stored as a chunked zarr array with multiscales metadata describing axes and resolution levels. Only the first dataset (highest resolution) is read.