Read a vlen-utf8 encoded string array from zarr v2 store
Source:R/AnnDataEncoding.R
dot-zarr_read_strings.RdAnnData zarr stores encode string arrays using the vlen-utf8 filter. Each string in the chunk is stored as a 4-byte little-endian int32 length prefix followed by that many bytes of UTF-8 text.